==> humhub-1.15.3.tar.gz: humhub-1.15.3/protected/humhub/modules/admin/messages/ko/user.php <==
<?php
return array (
  '<strong>Information</strong>' => '',
  '<strong>Profile</strong> Permissions' => '',
  '<strong>Settings</strong> and Configuration' => '',
  '<strong>User</strong> administration' => '',
  '<strong>Warning:</strong> All individual profile permission settings are reset to the default values!' => '',
  'Accept user: <strong>{displayName}</strong> ' => '',
  'Account' => '',
  'Account Request for \'{displayName}\' has been approved.' => '',
  'Account Request for \'{displayName}\' has been declined.' => '',
  'Actions' => '확인',
  'Active users' => '',
  'Add Groups...' => '',
  'Add new category' => '',
  'Add new field' => '',
  'Add new group' => '',
  'Add new members...' => '',
  'Add new user' => '',
  'Administrator group could not be deleted!' => '',
  'All open registration invitations were successfully deleted.' => '',
  'All the personal data of this user will be irrevocably deleted.' => '',
  'Allow' => '허용',
  'Allow users to block each other' => '',
  'Allow users to set individual permissions for their own profile?' => '',
  'Allow visitors limited access to content without an account (Adds visibility: "Guest")' => '',
  'Applied to new or existing users without any other group membership.' => '',
  'Apply' => '',
  'Approve' => '',
  'Approve all selected' => '',
  'Are you really sure that you want to disable this user?' => '',
  'Are you really sure that you want to enable this user?' => '',
  'Are you really sure that you want to impersonate this user?' => '',
  'Are you really sure? The selected users will be approved and notified by e-mail.' => '',
  'Are you really sure? The selected users will be deleted and notified by e-mail.' => '',
  'Are you really sure? Users who are not assigned to another group are automatically assigned to the default group.' => '',
  'Are you sure that you want to delete following user?' => '',
  'Cancel' => '취소',
  'Click here to review' => '',
  'Confirm user deletion' => '',
  'Could not approve the user!' => '',
  'Could not decline the user!' => '',
  'Could not load category.' => '',
  'Create new group' => '',
  'Create new profile category' => '',
  'Create new profile field' => '',
  'Deactivate' => '비활성화',
  'Deactivate individual profile permissions?' => '',
  'Decline' => '거부',
  'Decline & delete user: <strong>{displayName}</strong>' => '',
  'Decline all selected' => '',
  'Default' => '기본',
  'Default Profile Permissions' => '',
  'Default Sorting' => '',
  'Default content of the registration approval email' => '',
  'Default content of the registration denial email' => '',
  'Default group can not be deleted!' => '',
  'Default user idle timeout, auto-logout (in seconds, optional)' => '',
  'Default user profile visibility' => '',
  'Delete' => '삭제',
  'Delete All' => '',
  'Delete all contributions of this user' => '',
  'Delete invitation' => '',
  'Delete invitation?' => '',
  'Delete spaces which are owned by this user' => '',
  'Deleted' => '삭제됨',
  'Deleted invitation' => '',
  'Deleted users' => '',
  'Disable' => '',
  'Disabled' => '장애가있는',
  'Disabled users' => '',
  'Do not change placeholders like {displayName} if you want them to be automatically filled by the system. To reset the email content fields with the system default, leave them empty.' => '',
  'Edit' => '편집',
  'Edit category' => '',
  'Edit profile category' => '',
  'Edit profile field' => '',
  'Edit user: {name}' => '',
  'Enable' => '',
  'Enable individual profile permissions' => '',
  'Enabled' => '',
  'First name' => '',
  'Group Manager' => '',
  'Group not found!' => '',
  'Group user not found!' => '',
  'Groups' => '그룹',
  'Hello {displayName},

Your account has been activated.

Click here to login:
{loginUrl}

Kind Regards
{AdminName}

' => '',
  'Hello {displayName},

Your account request has been declined.

Kind Regards
{AdminName}

' => '',
  'Here you can create or edit profile categories and fields.' => '',
  'Hide online status of users' => '',
  'If individual profile permissions are not allowed, the following settings are unchangeable for all users. If individual profile permissions are allowed, the settings are only set as defaults that users can customise. The following entries are then displayed in the same form in the users profile settings:' => '',
  'If this option is not selected, the ownership of the spaces will be transferred to your account.' => '',
  'Impersonate' => '',
  'Include captcha in registration form' => '',
  'Information 1' => '',
  'Information 2' => '',
  'Information 3' => '',
  'Invisible' => '',
  'Invite new people' => '',
  'Invite not found!' => '',
  'Last login' => '마지막 로그인',
  'Last name' => '',
  'List pending registrations' => '',
  'Make the group selectable at registration.' => '',
  'Manage group: {groupName}' => '',
  'Manage groups' => '',
  'Manage profile attributes' => '',
  'Member since' => '',
  'Members' => '',
  'Members can invite external users by email' => '',
  'Members can invite external users by link' => '',
  'Message' => '',
  'Min value is 20 seconds. If not set, session will timeout after 1400 seconds (24 minutes) regardless of activity (default session timeout)' => '',
  'New approval requests' => '',
  'New users can register' => '',
  'No' => '',
  'No users were selected.' => '',
  'No value found!' => '',
  'None' => '',
  'Not visible' => '',
  'One or more user needs your approval as group admin.' => '',
  'Only applicable when limited access for non-authenticated users is enabled. Only affects new users.' => '',
  'Overview' => '',
  'Password' => '',
  'Pending approvals' => '',
  'Pending user approvals' => '',
  'People' => '사용자',
  'Permanently delete' => '',
  'Permissions' => '권한',
  'Prioritised User Group' => '',
  'Profile Permissions' => '',
  'Profiles' => '',
  'Protected' => '',
  'Protected group can not be deleted!' => '',
  'Remove from group' => '',
  'Require group admin approval after registration' => '',
  'Resend invitation email' => '',
  'Save' => '저장',
  'Search by name, email or id.' => '',
  'Select Groups' => '',
  'Select a prioritised group whose members are displayed before all others when the sorting option \'Default\' is selected. The users within the group and the users outside the group are additionally sorted by their last login.' => '',
  'Select the profile fields you want to add as columns' => '',
  'Select which user information should be displayed in the \'People\' overview. You can select any profile fields, even those you have created individually. ' => '',
  'Send & decline' => '',
  'Send & save' => '',
  'Send invitation email' => '',
  'Send invitation email again?' => '',
  'Send notifications to users when added to or removed from the group.' => '',
  'Settings' => '설정',
  'Show group selection at registration' => '',
  'Subject' => '',
  'The Space memberships of all group members will be updated. This may take up to several minutes.' => '',
  'The following list contains all pending sign-ups and invites.' => '',
  'The following list contains all registered users awaiting an approval.' => '',
  'The registration was approved and the user was notified by email.' => '',
  'The registration was declined and the user was notified by email.' => '',
  'The registrations were approved and the users were notified by email.' => '',
  'The registrations were declined and the users were notified by email.' => '',
  'The selected invitations have been successfully deleted!' => '',
  'The user is the owner of these spaces:' => '',
  'This option allows you to determine whether users may set individual permissions for their own profiles.' => '',
  'This overview contains a list of each registered user with actions to view, edit and delete users.' => '',
  'This user owns no spaces.' => '',
  'Unapproved' => '',
  'User deletion process queued.' => '',
  'User is already a member of this group.' => '',
  'User not found!' => '유저를 찾지 못했습니다!',
  'Users can be assigned to different groups (e.g. teams, departments etc.) with specific standard spaces, group managers and permissions.' => '',
  'Using this option any contributions (e.g. contents, comments or likes) of this user will be irrevocably deleted.' => '',
  'View profile' => '',
  'Visible for members only' => '',
  'Visible for members+guests' => '',
  'Will be used as a filter in \'People\'.' => '',
  'Yes' => '',
  'You can only delete empty categories!' => '',
  'You cannot delete yourself!' => '',
  'never' => '',
);

==> humhub-1.16.2.tar.gz: humhub-1.16.2/protected/humhub/modules/admin/messages/ko/user.php <==
<?php
return array (
  '<strong>Information</strong>' => '',
  '<strong>Profile</strong> Permissions' => '',
  '<strong>Settings</strong> and Configuration' => '',
  '<strong>User</strong> administration' => '',
  '<strong>Warning:</strong> All individual profile permission settings are reset to the default values!' => '',
  'About the account request for \'{displayName}\'.' => '',
  'Accept user: <strong>{displayName}</strong> ' => '',
  'Account' => '',
  'Account Request for \'{displayName}\' has been approved.' => '',
  'Account Request for \'{displayName}\' has been declined.' => '',
  'Actions' => '확인',
  'Active users' => '',
  'Add Groups...' => '',
  'Add new category' => '',
  'Add new field' => '',
  'Add new group' => '',
  'Add new members...' => '',
  'Add new user' => '',
  'Administrator group could not be deleted!' => '',
  'All open registration invitations were successfully deleted.' => '',
  'All the personal data of this user will be irrevocably deleted.' => '',
  'Allow' => '허용',
  'Allow users to block each other' => '',
  'Allow users to set individual permissions for their own profile?' => '',
  'Allow visitors limited access to content without an account (Adds visibility: "Guest")' => '',
  'Applied to new or existing users without any other group membership.' => '',
  'Apply' => '',
  'Approve' => '',
  'Approve all selected' => '',
  'Are you really sure that you want to disable this user?' => '',
  'Are you really sure that you want to enable this user?' => '',
  'Are you really sure that you want to impersonate this user?' => '',
  'Are you really sure? The selected users will be approved and notified by e-mail.' => '',
  'Are you really sure? The selected users will be deleted and notified by e-mail.' => '',
  'Are you really sure? The selected users will be notified by e-mail.' => '',
  'Are you really sure? Users who are not assigned to another group are automatically assigned to the default group.' => '',
  'Are you sure that you want to delete following user?' => '',
  'Cancel' => '취소',
  'Click here to review' => '',
  'Confirm user deletion' => '',
  'Could not approve the user!' => '',
  'Could not decline the user!' => '',
  'Could not load category.' => '',
  'Could not send the message to the user!' => '',
  'Create new group' => '',
  'Create new profile category' => '',
  'Create new profile field' => '',
  'Deactivate individual profile permissions?' => '',
  'Decline' => '거부',
  'Decline & delete user: <strong>{displayName}</strong>' => '',
  'Decline all selected' => '',
  'Default' => '기본',
  'Default Profile Permissions' => '',
  'Default Sorting' => '',
  'Default content of the email when sending a message to the user' => '',
  'Default content of the registration approval email' => '',
  'Default content of the registration denial email' => '',
  'Default group can not be deleted!' => '',
  'Default user idle timeout, auto-logout (in seconds, optional)' => '',
  'Default user profile visibility' => '',
  'Delete' => '삭제',
  'Delete All' => '',
  'Delete all contributions of this user' => '',
  'Delete invitation' => '',
  'Delete invitation?' => '',
  'Delete spaces which are owned by this user' => '',
  'Deleted' => '삭제됨',
  'Deleted invitation' => '',
  'Deleted users' => '',
  'Disable' => '비활성화',
  'Disabled' => '장애가있는',
  'Disabled users' => '',
  'Do not change placeholders like {displayName} if you want them to be automatically filled by the system. To reset the email content fields with the system default, leave them empty.' => '',
  'Edit' => '편집',
  'Edit category' => '',
  'Edit profile category' => '',
  'Edit profile field' => '',
  'Edit user: {name}' => '',
  'Email all selected' => '',
  'Enable' => '활성화',
  'Enable individual profile permissions' => '',
  'Enabled' => '활성화',
  'First name' => '',
  'Group Manager' => '',
  'Group not found!' => '',
  'Group user not found!' => '',
  'Groups' => '그룹',
  'Hello {displayName},

Your account creation is under review.
Could you tell us the motivation behind your registration?

Kind Regards
{AdminName}

' => '',
  'Hello {displayName},

Your account has been activated.

Click here to login:
{loginUrl}

Kind Regards
{AdminName}

' => '',
  'Hello {displayName},

Your account request has been declined.

Kind Regards
{AdminName}

' => '',
  'Here you can create or edit profile categories and fields.' => '',
  'Hide online status of users' => '',
  'If enabled, the Group Manager will need to approve registration.' => '',
  'If individual profile permissions are not allowed, the following settings are unchangeable for all users. If individual profile permissions are allowed, the settings are only set as defaults that users can customise. The following entries are then displayed in the same form in the users profile settings:' => '',
  'If this option is not selected, the ownership of the spaces will be transferred to your account.' => '',
  'Impersonate' => '',
  'Include captcha in registration form' => '',
  'Information 1' => '',
  'Information 2' => '',
  'Information 3' => '',
  'Invisible' => '',
  'Invite new people' => '',
  'Invite not found!' => '',
  'Last login' => '마지막 로그인',
  'Last name' => '',
  'List pending registrations' => '',
  'Make the group selectable at registration.' => '',
  'Manage group: {groupName}' => '',
  'Manage groups' => '',
  'Manage profile attributes' => '',
  'Member since' => '회원 가입 이후',
  'Members' => '회원',
  'Members can invite external users by email' => '',
  'Members can invite external users by link' => '',
  'Message' => '',
  'Min value is 20 seconds. If not set, session will timeout after 1400 seconds (24 minutes) regardless of activity (default session timeout)' => '',
  'New approval requests' => '',
  'New users can register' => '',
  'No' => '',
  'No users were selected.' => '',
  'No value found!' => '',
  'None' => '없음',
  'Not visible' => '',
  'One or more user needs your approval as group admin.' => '',
  'Only applicable when limited access for non-authenticated users is enabled. Only affects new users.' => '',
  'Overview' => '',
  'Password' => '',
  'Pending approvals' => '',
  'Pending user approvals' => '',
  'People' => '사용자',
  'Permanently delete' => '',
  'Permissions' => '권한',
  'Post-registration approval required' => '',
  'Prioritised User Group' => '',
  'Profile Permissions' => '',
  'Profiles' => '',
  'Protected' => '',
  'Protected group can not be deleted!' => '',
  'Remove from group' => '',
  'Resend invitation email' => '',
  'Save' => '저장',
  'Search by name, email or id.' => '',
  'Select Groups' => '',
  'Select a prioritised group whose members are displayed before all others when the sorting option \'Default\' is selected. The users within the group and the users outside the group are additionally sorted by their last login.' => '',
  'Select the profile fields you want to add as columns' => '',
  'Select which user information should be displayed in the \'People\' overview. You can select any profile fields, even those you have created individually. ' => '',
  'Send' => '보내기',
  'Send & decline' => '',
  'Send & save' => '',
  'Send a message' => '',
  'Send a message to <strong>{displayName}</strong> ' => '',
  'Send invitation email' => '',
  'Send invitation email again?' => '',
  'Send notifications to users when added to or removed from the group.' => '',
  'Settings' => '설정',
  'Show group selection at registration' => '',
  'Subject' => '',
  'The Space memberships of all group members will be updated. This may take up to several minutes.' => '',
  'The following list contains all pending sign-ups and invites.' => '',
  'The following list contains all registered users awaiting an approval.' => '',
  'The message has been sent by email.' => '',
  'The registration was approved and the user was notified by email.' => '',
  'The registration was declined and the user was notified by email.' => '',
  'The registrations were approved and the users were notified by email.' => '',
  'The registrations were declined and the users were notified by email.' => '',
  'The selected invitations have been successfully deleted!' => '',
  'The user is the owner of these spaces:' => '',
  'The users were notified by email.' => '',
  'This option allows you to determine whether users may set individual permissions for their own profiles.' => '',
  'This overview contains a list of each registered user with actions to view, edit and delete users.' => '',
  'This user owns no spaces.' => '',
  'Unapproved' => '',
  'User deletion process queued.' => '',
  'User is already a member of this group.' => '',
  'User not found!' => '유저를 찾지 못했습니다!',
  'Users can be assigned to different groups (e.g. teams, departments etc.) with specific standard spaces, group managers and permissions.' => '',
  'Using this option any contributions (e.g. contents, comments or likes) of this user will be irrevocably deleted.' => '',
  'View profile' => '',
  'Visible for members only' => '',
  'Visible for members+guests' => '',
  'Will be used as a filter in \'People\'.' => '',
  'Yes' => '',
  'You can only delete empty categories!' => '',
  'You cannot delete yourself!' => '',
  'never' => '',
  '{nbMsgSent} already sent' => '',
);
